abacusai.external_application — AbacusAI documentation

# abacusai.external_application

## Classes

`ExternalApplication` | An external application.

## Module Contents

class abacusai.external_application.ExternalApplication(client, name=None, externalApplicationId=None, deploymentId=None, description=None, logo=None, theme=None, userGroupIds=None, useCase=None, isAgent=None, status=None, deploymentConversationRetentionHours=None, managedUserService=None, predictionOverrides=None, isSystemCreated=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  An external application.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The name of the external application.

    - externalApplicationId (str) – The unique identifier of the external application.

    - deploymentId (str) – The deployment id associated with the external application.

    - description (str) – The description of the external application.

    - logo (str) – The logo.

    - theme (dict) – The theme used for the External Application.

    - userGroupIds (list) – A list of App User Groups with access to this external application

    - useCase (str) – Use Case of the project of this deployment

    - isAgent (bool) – Whether the external application is an agent.

    - status (str) – The status of the deployment.

    - deploymentConversationRetentionHours (int) – The retention policy for the external application.

    - managedUserService (str) – The external service that is managing the user accounts.

    - predictionOverrides (dict) – The prediction overrides for the external application.

    - isSystemCreated (bool) – Whether the external application is system created.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  update(name=None, description=None, theme=None, deployment_id=None, deployment_conversation_retention_hours=None, reset_retention_policy=False)

    Updates an External Application.

    Parameters:

      - name (str) – The name of the External Application.

      - description (str) – The description of the External Application. This will be shown to users when they access the External Application.

      - theme (dict) – The visual theme of the External Application.

      - deployment_id (str) – The ID of the deployment to use.

      - deployment_conversation_retention_hours (int) – The number of hours to retain the conversations for.

      - reset_retention_policy (bool) – If true, the retention policy will be removed.

    Returns:

      The updated External Application.

    Return type:

      ExternalApplication

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      ExternalApplication

  describe()

    Describes an External Application.

    Parameters:

      external_application_id (str) – The ID of the External Application.

    Returns:

      The External Application.

    Return type:

      ExternalApplication

  delete()

    Deletes an External Application.

    Parameters:

      external_application_id (str) – The ID of the External Application.